<?php

namespace Drupal\Tests\mailgroup\Kernel;

use Drupal\Core\Session\AccountInterface;
use Drupal\KernelTests\Core\Entity\EntityKernelTestBase;

/**
 * Defines a base for mail group kernel tests.
 */
abstract class MailGroupKernelTestBase extends EntityKernelTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = ['options', 'mailgroup', 'mailgroup_test_config'];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $this->installConfig(['mailgroup', 'mailgroup_test_config']);
    $this->installSchema('mailgroup', ['mailgroup_config']);
    $this->installEntitySchema('mailgroup');
    $this->installEntitySchema('mailgroup_type');

    $this->setCurrentUser($this->createUser());
  }

  /**
   * Sets the current user.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The account to set as the current user.
   */
  protected function setCurrentUser(AccountInterface $account) {
    $this->container->get('current_user')->setAccount($account);
  }

  /**
   * Gets the current user.
   *
   * @return \Drupal\Core\Session\AccountInterface
   *   The current user.
   */
  protected function getCurrentUser() {
    return $this->container->get('current_user')->getAccount();
  }

  /**
   * Creates a mail group.
   *
   * @param array $values
   *   (optional) The values used to create the mail group.
   *
   * @return \Drupal\mailgroup\Entity\MailGroup
   *   The created mail group entity.
   */
  protected function createMailGroup(array $values = []) {
    $storage = $this->entityTypeManager->getStorage('mailgroup');
    $mailgroup = $storage->create($values + [
      'type' => 'default',
      'name' => $this->randomString(),
    ]);
    $mailgroup->enforceIsNew();
    $storage->save($mailgroup);

    return $mailgroup;
  }

  /**
   * Creates a mail group type.
   *
   * @param array $values
   *   (optional) The values used to create the mail group type.
   *
   * @return \Drupal\mailgroup\Entity\MailGroupType
   *   The created mail group type entity.
   */
  protected function createMailGroupType(array $values = []) {
    $storage = $this->entityTypeManager->getStorage('mailgroup_type');
    $mailgroup_type = $storage->create($values + [
      'id' => $this->randomMachineName(),
      'label' => $this->randomString(),
    ]);
    $storage->save($mailgroup_type);

    return $mailgroup_type;
  }

}
