<?php

namespace Drupal\Tests\mailgroup\Kernel;

use Drupal\mailgroup\Plugin\Mailgroup\Connection\Basic;

/**
 * Tests mail group entities.
 *
 * @group mailgroup
 */
class MailGroupTest extends MailGroupKernelTestBase {

  /**
   * Tests getting the name of a mail group.
   */
  public function testGetName() {
    $name = $this->randomString();
    $mailgroup = $this->createMailGroup(['name' => $name]);
    $this->assertEquals($name, $mailgroup->getName());
  }

  /**
   * Tests setting the name of a mail group.
   *
   * @depends testGetName
   */
  public function testSetName() {
    $name = $this->randomString();
    $mailgroup = $this->createMailGroup();
    $mailgroup->setName($name);
    $this->assertEquals($name, $mailgroup->getName());
  }

  /**
   * Tests getting the owner ID of a mail group.
   */
  public function testGetOwnerId() {
    $owner = $this->createUser();
    $mailgroup = $this->createMailGroup(['uid' => $owner->id()]);
    $this->assertEquals($owner->id(), $mailgroup->getOwnerId());
  }

  /**
   * Tests setting the owner ID of a mail group.
   *
   * @depends testGetOwnerId
   */
  public function testSetOwnerId() {
    $owner = $this->createUser();
    $mailgroup = $this->createMailGroup();
    $mailgroup->setOwnerId($owner->id());
    $this->assertEquals($owner->id(), $mailgroup->getOwnerId());
  }

  /**
   * Tests getting the owner of a mail group.
   *
   * @depends testGetOwnerId
   */
  public function testGetOwner() {
    $owner = $this->createUser();
    $mailgroup = $this->createMailGroup(['uid' => $owner->id()]);
    $saved_owner = $mailgroup->getOwner();
    $this->assertEquals($owner->id(), $saved_owner->id());
  }

  /**
   * Tests setting the owner of a mail group.
   *
   * @depends testGetOwnerId
   */
  public function testSetOwner() {
    $owner = $this->createUser();
    $mailgroup = $this->createMailGroup();
    $mailgroup->setOwner($owner);
    $saved_owner = $mailgroup->getOwner();
    $this->assertEquals($owner->id(), $saved_owner->id());
  }

  /**
   * Tests getting the email address of a mail group.
   */
  public function testGetEmail() {
    $email = 'test@test.com';
    $mailgroup = $this->createMailGroup(['email' => $email]);
    $this->assertEquals($email, $mailgroup->getEmail());
  }

  /**
   * Tests setting the email address of a mail group.
   *
   * @depends testGetEmail
   */
  public function testSetEmail() {
    $email = 'new@test.com';
    $mailgroup = $this->createMailGroup();
    $mailgroup->setEmail($email);
    $this->assertEquals($email, $mailgroup->getEmail());
  }

  /**
   * Tests getting the connection plugin of a mail group.
   */
  public function testGetConnectionPlugin() {
    $mailgroup = $this->createMailGroup(['plugin' => 'basic']);
    $this->assertInstanceOf(Basic::class, $mailgroup->getConnectionPlugin());
  }

  /**
   * Tests getting the connection plugin of a mail group.
   */
  public function testGetConnectionPluginNull() {
    $mailgroup = $this->createMailGroup();
    $this->assertEquals(NULL, $mailgroup->getConnectionPlugin());
  }

  /**
   * Tests setting the connection plugin of a mail group.
   *
   * @depends testGetConnectionPlugin
   */
  public function testSetConnectionPlugin() {
    $mailgroup = $this->createMailGroup();
    $mailgroup->setConnectionPlugin('basic');
    $this->assertInstanceOf(Basic::class, $mailgroup->getConnectionPlugin());
  }

  /**
   * Tests getting the status of a mail group.
   */
  public function testIsActive() {
    $status = TRUE;
    $mailgroup = $this->createMailGroup(['status' => $status]);
    $this->assertEquals($status, $mailgroup->isActive());
  }

  /**
   * Tests setting the status of a mail group.
   *
   * @depends testIsActive
   */
  public function testSetActive() {
    $status = TRUE;
    $mailgroup = $this->createMailGroup(['status' => $status]);
    $mailgroup->setActive($status);
    $this->assertEquals($status, $mailgroup->isActive());
  }

  /**
   * Tests getting the prepend name setting of a mail group.
   */
  public function testPrependName() {
    $prepend_name = TRUE;
    $mailgroup = $this->createMailGroup(['prepend_name' => $prepend_name]);
    $this->assertEquals($prepend_name, $mailgroup->prependName());
  }

  /**
   * Tests getting the reply to setting of a mail group.
   */
  public function testReplyTo() {
    $reply_to = 'sender';
    $mailgroup = $this->createMailGroup(['reply_to' => $reply_to]);
    $this->assertEquals($reply_to, $mailgroup->replyTo());
  }

}
